@@ -13,7 +13,7 @@
 
 #include "dfilter-int.h"
 
-gboolean
+bool
 dfw_semcheck(dfwork_t *dfw);
 
 ftenum_t
@@ -25,7 +25,7 @@ check_function(dfwork_t *dfw, stnode_t *st_node, ftenum_t lhs_ftype);
 ftenum_t
 check_slice(dfwork_t *dfw, stnode_t *st, ftenum_t lhs_ftype);
 
-gboolean
+bool
 compatible_ftypes(ftenum_t a, ftenum_t b);
 
 #endif
