@@ -30,19 +30,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 /*
@@ -676,7 +664,7 @@ dissect_atn_ulcs(
             1,
             value_ses_pres,
             "%s (0x%02x)",
-            val_to_str( value_ses_pres & ATN_SES_PRES_MASK , atn_pres_vals, "?"),
+            val_to_str_const( value_ses_pres & ATN_SES_PRES_MASK, atn_pres_vals, "?"),
             value_pres);
 
         /* PPDU errorcode in case of SRF/CPR */
@@ -831,7 +819,7 @@ void proto_register_atn_ulcs (void)
           HFILL}},
       { &hf_atn_pres_pdu_type,
         { "PDU type", "atn-ulcs.pres.pdu_type",
-          FT_UINT8,
+          FT_UINT16,
           BASE_HEX,
           NULL,
           ATN_SES_PRES_MASK,
@@ -890,7 +878,7 @@ void proto_reg_handoff_atn_ulcs(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
