@@ -46,11 +46,8 @@ static gboolean rdn_one_value = FALSE; /* have we seen one value in an RDN yet *
 static gboolean dn_one_rdn = FALSE; /* have we seen one RDN in a DN yet */
 static gboolean doing_attr = FALSE;
 
-#define MAX_RDN_STR_LEN   64
-#define MAX_DN_STR_LEN    (20 * MAX_RDN_STR_LEN)
-
-static char *last_dn = NULL;
-static char *last_rdn = NULL;
+static wmem_strbuf_t *last_dn_buf = NULL;
+static wmem_strbuf_t *last_rdn_buf = NULL;
 
 static int ava_hf_index;
 #define MAX_FMT_VALS   32
@@ -68,8 +65,8 @@ x509if_frame_end(void)
   dn_one_rdn = FALSE;
   doing_attr = FALSE;
 
-  last_dn = NULL;
-  last_rdn = NULL;
+  last_dn_buf = NULL;
+  last_rdn_buf = NULL;
   last_ava = NULL;
 }
 
@@ -77,7 +74,7 @@ x509if_frame_end(void)
 
 const char * x509if_get_last_dn(void)
 {
-  return last_dn;
+  return last_dn_buf ? wmem_strbuf_get_str(last_dn_buf) : NULL;
 }
 
 gboolean x509if_register_fmt(int hf_index, const gchar *fmt)
