@@ -182,7 +182,7 @@ static const value_string comp_tlv_tag_vals[] = {
 	{ 0x19, "Event list" },
 	{ 0x1a, "GSM/3G Cause" },
 	{ 0x1b, "Location status" },
-	{ 0x1c, "transaction identifier" },
+	{ 0x1c, "Transaction identifier" },
 	{ 0x1d, "GSM/3G BCCH channel list" },
 	{ 0x1e, "Icon identifier" },
 	{ 0x1f, "Item Icon identifier list" },
@@ -680,8 +680,8 @@ static const value_string bearer_vals[] = {
 static const value_string bearer_descr_vals[] = {
 	{ 0x01, "CSD" },
 	{ 0x02, "GPRS / UTRAN packet service / E-UTRAN" },
-	{ 0x03, "default bearer for requested transport layer" },
-	{ 0x04, "local link technology independent" },
+	{ 0x03, "Default bearer for requested transport layer" },
+	{ 0x04, "Local link technology independent" },
 	{ 0x05, "Bluetooth" },
 	{ 0x06, "IrDA" },
 	{ 0x07, "RS232" },
@@ -1093,11 +1093,11 @@ dissect_cat(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 			if (len < 3)
 				break;
 			proto_tree_add_item_ret_uint(elem_tree, hf_ctlv_cmd_nr, tvb, pos, 1, ENC_BIG_ENDIAN, &cmd_nr);
-			if (cmd_nr == 0x40) {
+			proto_tree_add_item_ret_uint(elem_tree, hf_ctlv_cmd_type, tvb, pos+1, 1, ENC_BIG_ENDIAN, &g8);
+			if (g8 == 0x40) { /* OPEN CHANNEL */
 				ims_event = TRUE;
 				dns_server = TRUE;
 			}
-			proto_tree_add_item_ret_uint(elem_tree, hf_ctlv_cmd_type, tvb, pos+1, 1, ENC_BIG_ENDIAN, &g8);
 			/* append command type to INFO column */
 			col_append_fstr(pinfo->cinfo, COL_INFO, "%s ",
 					val_to_str_ext(g8, &cmd_type_vals_ext, "%02x "));
