@@ -45,6 +45,8 @@
 void proto_register_flip(void);
 void proto_reg_handoff_flip(void);
 
+static dissector_handle_t flip_handle;
+
 static int proto_flip = -1;
 
 /* BASIC */
@@ -81,7 +83,7 @@ static gint ett_flip_payload = -1;
 
 static void flip_prompt(packet_info *pinfo _U_, gchar* result)
 {
-    g_snprintf(result, MAX_DECODE_AS_PROMPT_LEN, "Decode FLIP payload protocol as");
+    snprintf(result, MAX_DECODE_AS_PROMPT_LEN, "Decode FLIP payload protocol as");
 }
 
 /* Dissect the checksum extension header. */
@@ -152,8 +154,7 @@ dissect_flip_chksum_hdr(tvbuff_t    *tvb,
         col_add_fstr(pinfo->cinfo, COL_INFO,
                      "Checksum 0x%04x [%s] (computed 0x%04x)",
                      chksum_hdr_chksum,
-                     ((chksum_hdr_chksum == computed_chksum) ?
-                      "Correct" : "Incorrect"),
+                     "Incorrect",
                      computed_chksum);
     }
 
@@ -432,16 +433,13 @@ proto_register_flip(void)
 
     module_t *flip_module;
 
-    proto_flip = proto_register_protocol(
-        "NSN FLIP", /* name */
-        "FLIP",     /* short name */
-        "flip"      /* abbrev */
-        );
+    proto_flip = proto_register_protocol("NSN FLIP", "FLIP", "flip");
+    flip_handle = register_dissector("flip", dissect_flip, proto_flip);
 
     proto_register_field_array(proto_flip, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
 
-    flip_module = prefs_register_protocol(proto_flip, NULL);
+    flip_module = prefs_register_protocol_obsolete(proto_flip);
 
     /* Register preferences - now obsolete because of Decode As*/
     prefs_register_obsolete_preference(flip_module, "decoding_mode");
@@ -459,9 +457,6 @@ proto_register_flip(void)
 void
 proto_reg_handoff_flip(void)
 {
-    dissector_handle_t flip_handle;
-
-    flip_handle = create_dissector_handle(dissect_flip, proto_flip);
     dissector_add_uint("ethertype", ETHERTYPE_FLIP, flip_handle);
 } /* proto_reg_handoff_flip() */
 
