@@ -111,7 +111,7 @@ static int hf_mpls_pm_timestamp4_unk = -1;
  * http://www.iana.org/assignments/mpls-lsp-ping-parameters
  * Registry Name: 'Loss/Delay Measurement Control Code: Query Codes'
  */
-const range_string mpls_pm_query_ctrl_code_rvals[] = {
+static const range_string mpls_pm_query_ctrl_code_rvals[] = {
     { 0x00, 0x00, "In-band Response Requested"     },
     { 0x01, 0x01, "Out-of-band Response Requested" },
     { 0x02, 0x02, "No Response Requested"          },
@@ -124,7 +124,7 @@ const range_string mpls_pm_query_ctrl_code_rvals[] = {
  * http://www.iana.org/assignments/mpls-lsp-ping-parameters
  * Registry Name: 'Loss/Delay Measurement Control Code: Response Codes'
  */
-const range_string mpls_pm_response_ctrl_code_rvals[] = {
+static const range_string mpls_pm_response_ctrl_code_rvals[] = {
     { 0x00, 0x00, "Reserved"                            },
     { 0x01, 0x01, "Success"                             },
     { 0x02, 0x02, "Data Format Invalid"                 },
@@ -174,7 +174,7 @@ static const value_string pmt_vals[] = {
 #define MPLS_PM_TSF_SEQ 1
 #define MPLS_PM_TSF_NTP 2
 #define MPLS_PM_TSF_PTP 3
-const range_string mpls_pm_time_stamp_format_rvals[] = {
+static const range_string mpls_pm_time_stamp_format_rvals[] = {
     { MPLS_PM_TSF_NULL, MPLS_PM_TSF_NULL,
       "Null Timestamp"                                   },
     { MPLS_PM_TSF_SEQ, MPLS_PM_TSF_SEQ,
@@ -484,9 +484,9 @@ mpls_pm_build_cinfo(tvbuff_t *tvb, packet_info *pinfo, const char *str_pmt,
         col_add_fstr(pinfo->cinfo, COL_INFO,
                      "Response, sid: %u, code: %s (%u)",
                      *sid,
-                     rval_to_str(*code,
-                                 mpls_pm_response_ctrl_code_rvals,
-                                 "Unknown"),
+                     rval_to_str_const(*code,
+                                       mpls_pm_response_ctrl_code_rvals,
+                                       "Unknown"),
                      *code);
     }
 }
@@ -869,7 +869,7 @@ proto_register_mpls_pm(void)
             &hf_mpls_pm_flags_r,
             {
                 "Response indicator (R)", "mpls_pm.flags.r",
-                FT_BOOLEAN, 4, TFS(&tfs_set_notset), MPLS_PM_FLAGS_R,
+                FT_BOOLEAN, 8, TFS(&tfs_set_notset), MPLS_PM_FLAGS_R,
                 NULL, HFILL
             }
         },
@@ -878,7 +878,7 @@ proto_register_mpls_pm(void)
             {
                 "Traffic-class-specific measurement indicator (T)",
                 "mpls_pm.flags.t",
-                FT_BOOLEAN, 4, TFS(&tfs_set_notset), MPLS_PM_FLAGS_T,
+                FT_BOOLEAN, 8, TFS(&tfs_set_notset), MPLS_PM_FLAGS_T,
                 NULL, HFILL
             }
         },
@@ -887,7 +887,7 @@ proto_register_mpls_pm(void)
             {
                 "Reserved",
                 "mpls_pm.flags.res",
-                FT_BOOLEAN, 4, TFS(&tfs_set_notset), MPLS_PM_FLAGS_RES,
+                FT_BOOLEAN, 8, TFS(&tfs_set_notset), MPLS_PM_FLAGS_RES,
                 NULL, HFILL
             }
         },
@@ -932,7 +932,7 @@ proto_register_mpls_pm(void)
             &hf_mpls_pm_dflags_x,
             {
                 "Extended counter format indicator (X)", "mpls_pm.dflags.x",
-                FT_BOOLEAN, 4, TFS(&tfs_set_notset), MPLS_PM_DFLAGS_X,
+                FT_BOOLEAN, 8, TFS(&tfs_set_notset), MPLS_PM_DFLAGS_X,
                 NULL, HFILL
             }
         },
@@ -940,7 +940,7 @@ proto_register_mpls_pm(void)
             &hf_mpls_pm_dflags_b,
             {
                 "Octet/Byte count indicator (B)", "mpls_pm.dflags.b",
-                FT_BOOLEAN, 4, TFS(&tfs_set_notset), MPLS_PM_DFLAGS_B,
+                FT_BOOLEAN, 8, TFS(&tfs_set_notset), MPLS_PM_DFLAGS_B,
                 NULL, HFILL
             }
         },
@@ -949,7 +949,7 @@ proto_register_mpls_pm(void)
             {
                 "Reserved",
                 "mpls_pm.dflags.res",
-                FT_BOOLEAN, 4, NULL, MPLS_PM_DFLAGS_RES,
+                FT_BOOLEAN, 8, NULL, MPLS_PM_DFLAGS_RES,
                 NULL, HFILL
             }
         },
@@ -1493,7 +1493,7 @@ proto_reg_handoff_mpls_pm(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
