@@ -26,6 +26,7 @@ typedef enum {
 	RDP_CHANNEL_CLIPBOARD,
 	RDP_CHANNEL_SOUND,
 	RDP_CHANNEL_DISK,
+	RDP_CHANNEL_RAIL,
 } rdp_known_channel_t;
 
 typedef struct _rdp_channel_def {
@@ -39,6 +40,7 @@ typedef struct _rdp_server_address {
 	guint16 port;
 } rdp_server_address_t;
 
+
 typedef struct _rdp_conv_info_t {
   guint32 staticChannelId;
   guint32 messageChannelId;
@@ -47,9 +49,13 @@ typedef struct _rdp_conv_info_t {
   guint32 licenseAgreed;
   rdp_server_address_t serverAddr;
   guint8  maxChannels;
+  gboolean isRdstls;
   rdp_channel_def_t staticChannels[RDP_MAX_CHANNELS+1];
 } rdp_conv_info_t;
 
-extern gboolean rdp_isServerAddressTarget(packet_info *infos);
+gint dissect_rdp_bandwidth_req(tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *tree, gboolean from_server);
+void rdp_transport_set_udp_conversation(const address *serverAddr, guint16 serverPort, gboolean reliable, guint32 reqId,
+		guint8 *cookie, conversation_t *conv);
+conversation_t *rdp_find_tcp_conversation_from_udp(conversation_t *udp);
 
 #endif /* __PACKET_RDP_H__ */
