@@ -210,12 +210,15 @@ WSLUA_CONSTRUCTOR DissectorTable_new (lua_State *L) {
         proto_id = proto_get_id_by_short_name(proto->name);
     }
 
+    name = g_strdup(name);
+    ui_name = g_strdup(ui_name);
+
     dt->table = (type == FT_NONE) ?
         register_decode_as_next_proto(proto_id, name, ui_name, NULL) :
         register_dissector_table(name, ui_name, proto_id, type, base);
     dt->heur_list = NULL;
-    dt->name = g_strdup(name);
-    dt->ui_name = g_strdup(ui_name);
+    dt->name = name;
+    dt->ui_name = ui_name;
     dt->created = TRUE;
     dt->expired = FALSE;
 
