@@ -1163,6 +1163,8 @@ class TestSharkd:
         # just skip for now.
         if not features.have_nghttp2:
             pytest.skip('Requires nghttp2.')
+        if not features.have_brotli:
+            pytest.skip('Requires brotli.')
 
         check_sharkd_session((
             {"jsonrpc":"2.0", "id":1, "method":"load",
