@@ -12,11 +12,12 @@
 #include "capture_file_properties_dialog.h"
 #include <ui_capture_file_properties_dialog.h>
 
+#include "ui/simple_dialog.h"
 #include "ui/summary.h"
 
 #include "wsutil/str_util.h"
 #include "wsutil/utf8_entities.h"
-#include "ui/version_info.h"
+#include "wsutil/version_info.h"
 
 #include <ui/qt/utils/qt_ui_utils.h>
 #include "main_application.h"
@@ -117,13 +118,11 @@ static const QString para_tmpl_ = "<p>%1</p>\n";
 
 QString CaptureFilePropertiesDialog::summaryToHtml()
 {
-    summary_tally summary;
+    summary_tally summary = {};
     double seconds = 0.0;
     double disp_seconds = 0.0;
     double marked_seconds = 0.0;
 
-    memset(&summary, 0, sizeof(summary_tally));
-
     QString table_begin, table_end;
     QString table_row_begin, table_ul_row_begin, table_row_end;
     QString table_vheader_tmpl, table_hheader20_tmpl, table_hheader25_tmpl;
@@ -139,14 +138,17 @@ QString CaptureFilePropertiesDialog::summaryToHtml()
     table_hheader25_tmpl = "<td width=\"25%\"><u>%1</u></td>";
     table_data_tmpl = "<td>%1</td>";
 
-    if (!file_closed_) {
-        /* initial computations */
-        summary_fill_in(cap_file_.capFile(), &summary);
-#ifdef HAVE_LIBPCAP
-        summary_fill_in_capture(cap_file_.capFile(), &global_capture_opts, &summary);
-#endif
+    if (file_closed_) {
+        // We shouldn't be here since our menu item or the refresh button should be disabled.
+        return QString();
     }
 
+    /* initial computations */
+    summary_fill_in(cap_file_.capFile(), &summary);
+#ifdef HAVE_LIBPCAP
+    summary_fill_in_capture(cap_file_.capFile(), &global_capture_opts, &summary);
+#endif
+
     seconds = summary.stop_time - summary.start_time;
     disp_seconds = summary.filtered_stop - summary.filtered_start;
     marked_seconds = summary.marked_stop - summary.marked_start;
@@ -174,11 +176,6 @@ QString CaptureFilePropertiesDialog::summaryToHtml()
         << table_data_tmpl.arg(summary.file_sha256)
         << table_row_end;
 
-    out << table_row_begin
-        << table_vheader_tmpl.arg(tr("Hash (RIPEMD160)"))
-        << table_data_tmpl.arg(summary.file_rmd160)
-        << table_row_end;
-
     out << table_row_begin
         << table_vheader_tmpl.arg(tr("Hash (SHA1)"))
         << table_data_tmpl.arg(summary.file_sha1)
@@ -616,6 +613,20 @@ void CaptureFilePropertiesDialog::on_buttonBox_accepted()
     if (wtap_dump_can_write(cap_file_.capFile()->linktypes, WTAP_COMMENT_PER_SECTION))
     {
         gchar *str = qstring_strdup(ui->commentsTextEdit->toPlainText());
+
+        /*
+         * Make sure this would fit in a pcapng option.
+         *
+         * XXX - 65535 is the maximum size for an option in pcapng;
+         * what if another capture file format supports larger
+         * comments?
+         */
+        if (strlen(str) > 65535) {
+            /* It doesn't fit.  Tell the user and give up. */
+            simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
+                          "That comment is too large to save in a capture file.");
+            return;
+        }
         cf_update_section_comment(cap_file_.capFile(), str);
         emit captureCommentChanged();
         fillDetails();
