@@ -334,6 +334,7 @@ void RtpAnalysisDialog::deleteTabInfo(tab_info_t *tab_info)
     delete tab_info->jitter_vals;
     delete tab_info->diff_vals;
     delete tab_info->delta_vals;
+    delete tab_info->tab_name;
     // tab_info->tree_widget was deleted by ui
     // tab_info->statistics_label was deleted by ui
     rtpstream_info_free_data(&tab_info->stream);
@@ -350,6 +351,7 @@ int RtpAnalysisDialog::addTabUI(tab_info_t *new_tab)
             .arg(s_calc.dst_addr_str)
             .arg(s_calc.dst_port)
             .arg(int_to_qstring(s_calc.ssrc, 8, 16)));
+    rtpstream_info_calc_free(&s_calc);
 
     QWidget *tab = new QWidget();
     tab->setProperty("tab_data", QVariant::fromValue((void *)new_tab));
@@ -619,7 +621,7 @@ void RtpAnalysisDialog::on_actionSaveGraph_triggered()
     ui->tabWidget->setCurrentWidget(ui->graphTab);
 
     QString file_name, extension;
-    QDir path(mainApp->lastOpenDir());
+    QDir path(mainApp->openDialogInitialDir());
     QString pdf_filter = tr("Portable Document Format (*.pdf)");
     QString png_filter = tr("Portable Network Graphics (*.png)");
     QString bmp_filter = tr("Windows Bitmap (*.bmp)");
@@ -672,7 +674,7 @@ void RtpAnalysisDialog::tapReset(void *tapinfo_ptr)
     rtp_analysis_dialog->resetStatistics();
 }
 
-tap_packet_status RtpAnalysisDialog::tapPacket(void *tapinfo_ptr, packet_info *pinfo, epan_dissect_t *, const void *rtpinfo_ptr)
+tap_packet_status RtpAnalysisDialog::tapPacket(void *tapinfo_ptr, packet_info *pinfo, epan_dissect_t *, const void *rtpinfo_ptr, tap_flags_t)
 {
     RtpAnalysisDialog *rtp_analysis_dialog = dynamic_cast<RtpAnalysisDialog *>((RtpAnalysisDialog*)tapinfo_ptr);
     if (!rtp_analysis_dialog) return TAP_PACKET_DONT_REDRAW;
@@ -732,7 +734,7 @@ void RtpAnalysisDialog::resetStatistics()
 
 void RtpAnalysisDialog::addPacket(tab_info_t *tab, packet_info *pinfo, const _rtp_info *rtpinfo)
 {
-    rtppacket_analyse(&tab->stream.rtp_stats, pinfo, rtpinfo);
+    rtpstream_info_analyse_process(&tab->stream, pinfo, rtpinfo);
     new RtpAnalysisTreeWidgetItem(tab->tree_widget, &tab->stream.rtp_stats, pinfo, rtpinfo);
     tab->time_vals->append(tab->stream.rtp_stats.time / 1000);
     tab->jitter_vals->append(tab->stream.rtp_stats.jitter);
@@ -784,6 +786,7 @@ void RtpAnalysisDialog::updateStatistics()
                 .arg(s_calc.clock_drift_ms, 0, 'f', 0);
         stats_tables += QString("<tr><th align=\"left\">Freq Drift</th><td>%1 Hz (%2 %)</td></tr>") // XXX Terminology?
                 .arg(s_calc.freq_drift_hz, 0, 'f', 0).arg(s_calc.freq_drift_perc, 0, 'f', 2);
+        rtpstream_info_calc_free(&s_calc);
         stats_tables += "</table></p>\n";
 
         tabs_[i]->statistics_label->setText(stats_tables);
@@ -901,7 +904,7 @@ void RtpAnalysisDialog::saveCsv(RtpAnalysisDialog::StreamDirection direction)
     }
 
     QString file_path = WiresharkFileDialog::getSaveFileName(
-                this, caption, mainApp->lastOpenDir().absoluteFilePath("RTP Packet Data.csv"),
+                this, caption, mainApp->openDialogInitialDir().absoluteFilePath("RTP Packet Data.csv"),
                 tr("Comma-separated values (*.csv)"));
 
     if (file_path.isEmpty()) return;
@@ -1142,7 +1145,7 @@ QToolButton *RtpAnalysisDialog::addAnalyzeButton(QDialogButtonBox *button_box, Q
     analysis_button->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     analysis_button->setPopupMode(QToolButton::MenuButtonPopup);
 
-    ca = new QAction(tr("&Analyze"));
+    ca = new QAction(tr("&Analyze"), analysis_button);
     ca->setToolTip(tr("Open the analysis window for the selected stream(s)"));
     connect(ca, SIGNAL(triggered()), dialog, SLOT(rtpAnalysisReplace()));
     analysis_button->setDefaultAction(ca);
