@@ -65,164 +65,11 @@ int TabData::protoId() const
 }
 
 
-TrafficDataFilterProxy::TrafficDataFilterProxy(QObject *parent) :
-    QSortFilterProxyModel(parent)
-{}
-
-bool TrafficDataFilterProxy::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
-{
-    ATapDataModel * dataModel = qobject_cast<ATapDataModel *>(sourceModel());
-    if (dataModel) {
-        bool isFiltered = dataModel->data(dataModel->index(source_row, 0), ATapDataModel::ROW_IS_FILTERED).toBool();
-        if (dataModel->filter().length() > 0)
-            return ! isFiltered;
-    }
-
-    return QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
-}
-
-bool TrafficDataFilterProxy::lessThan(const QModelIndex &source_left, const QModelIndex &source_right) const
-{
-    if (! source_left.isValid() || ! qobject_cast<const ATapDataModel *>(source_left.model()))
-        return false;
-    if (! source_right.isValid() || ! qobject_cast<const ATapDataModel *>(source_right.model()))
-        return false;
-
-    ATapDataModel * model = qobject_cast<ATapDataModel *>(sourceModel());
-
-    if (! model || source_left.model() != model || source_right.model() != model)
-        return false;
-
-    QVariant datA = source_left.data(ATapDataModel::UNFORMATTED_DISPLAYDATA);
-    QVariant datB = source_right.data(ATapDataModel::UNFORMATTED_DISPLAYDATA);
-
-    bool is_address = false;
-    if (qobject_cast<EndpointDataModel *>(model) && source_left.column() == EndpointDataModel::ENDP_COLUMN_ADDR &&
-        source_left.column() == source_right.column()) {
-        is_address = true;
-    } else if (qobject_cast<ConversationDataModel *>(model) && (source_left.column() == ConversationDataModel::CONV_COLUMN_SRC_ADDR ||
-        source_left.column() == ConversationDataModel::CONV_COLUMN_DST_ADDR) && source_left.column() == source_right.column()) {
-        is_address = true;
-    }
-
-    if (is_address) {
-        bool result = false;
-        bool identical = false;
-        int addressTypeA = model->data(source_left, ATapDataModel::DATA_ADDRESS_TYPE).toInt();
-        int addressTypeB = model->data(source_right, ATapDataModel::DATA_ADDRESS_TYPE).toInt();
-        if (addressTypeA != 0 && addressTypeB != 0 && addressTypeA != addressTypeB) {
-            result = addressTypeA < addressTypeB;
-        } else if (addressTypeA != 0 && addressTypeA == addressTypeB) {
-
-            if (addressTypeA == AT_IPv4) {
-                quint32 valA = model->data(source_left, ATapDataModel::DATA_IPV4_INTEGER).value<quint32>();
-                quint32 valB = model->data(source_right, ATapDataModel::DATA_IPV4_INTEGER).value<quint32>();
-
-                result = valA < valB;
-                identical = valA == valB;
-            } else if (addressTypeA == AT_NUMERIC) {
-                quint32 valA = datA.toInt();
-                quint32 valB = datB.toInt();
-                result = valA < valB;
-                identical = valA == valB;
-            } else {
-                result = QString::compare(datA.toString(), datB.toString(), Qt::CaseInsensitive) < 0;
-                identical = QString::compare(datA.toString(), datB.toString(), Qt::CaseInsensitive) == 0;
-            }
-
-            int portColumn = EndpointDataModel::ENDP_COLUMN_PORT;
-            if (identical && qobject_cast<ConversationDataModel *>(model)) {
-                QModelIndex tstA, tstB;
-                if (source_left.column() == ConversationDataModel::CONV_COLUMN_SRC_ADDR) {
-                    portColumn = ConversationDataModel::CONV_COLUMN_SRC_PORT;
-                    int col = ConversationDataModel::CONV_COLUMN_DST_ADDR;
-                    tstA = model->index(source_left.row(), col);
-                    tstB = model->index(source_right.row(), col);
-                } else if (source_left.column() == ConversationDataModel::CONV_COLUMN_DST_ADDR) {
-                    portColumn = ConversationDataModel::CONV_COLUMN_DST_PORT;
-                    int col = ConversationDataModel::CONV_COLUMN_SRC_ADDR;
-                    tstA = model->index(source_left.row(), col);
-                    tstB = model->index(source_right.row(), col);
-                }
-
-                if (addressTypeA == AT_IPv4) {
-                    quint32 valX = model->data(tstA, ATapDataModel::DATA_IPV4_INTEGER).value<quint32>();
-                    quint32 valY = model->data(tstB, ATapDataModel::DATA_IPV4_INTEGER).value<quint32>();
-
-                    result = valX < valY;
-                    identical = valX == valY;
-                } else {
-                    result = QString::compare(model->data(tstA).toString().toLower(), model->data(tstB).toString(), Qt::CaseInsensitive) < 0;
-                    identical = QString::compare(model->data(tstA).toString().toLower(), model->data(tstB).toString(), Qt::CaseInsensitive) == 0;
-                }
-            }
-
-            if (! result && identical && ! model->portsAreHidden()) {
-                int portA = model->data(model->index(source_left.row(), portColumn)).toInt();
-                int portB = model->data(model->index(source_right.row(), portColumn)).toInt();
-                return portA < portB;
-            }
-        }
-
-        return result;
-    }
-
-    if (datA.canConvert<double>() && datB.canConvert<double>())
-        return datA.toDouble() < datB.toDouble();
-
-    return QSortFilterProxyModel::lessThan(source_left, source_right);
-}
-
-bool TrafficDataFilterProxy::filterAcceptsColumn(int source_column, const QModelIndex &) const
-{
-    if (hideColumns_.contains(source_column))
-        return false;
-
-    ATapDataModel * model = qobject_cast<ATapDataModel *>(sourceModel());
-    if (model) {
-        if (model->portsAreHidden()) {
-            if (qobject_cast<EndpointDataModel *>(model) && source_column == EndpointDataModel::ENDP_COLUMN_PORT)
-                return false;
-            if (qobject_cast<ConversationDataModel *>(model) &&
-                (source_column == ConversationDataModel::CONV_COLUMN_SRC_PORT || source_column == ConversationDataModel::CONV_COLUMN_DST_PORT))
-                return false;
-        }
-        if (! model->showTotalColumn()) {
-            if (qobject_cast<EndpointDataModel *>(model) &&
-                (source_column == EndpointDataModel::ENDP_COLUMN_PACKETS_TOTAL || source_column == EndpointDataModel::ENDP_COLUMN_BYTES_TOTAL))
-                return false;
-            if (qobject_cast<ConversationDataModel *>(model) &&
-                (source_column == ConversationDataModel::CONV_COLUMN_PACKETS_TOTAL || source_column == ConversationDataModel::CONV_COLUMN_BYTES_TOTAL))
-                return false;
-        }
-        if (qobject_cast<ConversationDataModel *>(model)) {
-            ConversationDataModel * convModel = qobject_cast<ConversationDataModel *>(model);
-            if (source_column == ConversationDataModel::CONV_COLUMN_CONV_ID && ! convModel->showConversationId(source_column))
-                return false;
-        }
-    }
-
-    return true;
-}
-
-void TrafficDataFilterProxy::setColumnVisibility(int column, bool visible)
-{
-    hideColumns_.removeAll(column);
-    if (!visible)
-        hideColumns_.append(column);
-    invalidateFilter();
-}
-
-bool TrafficDataFilterProxy::columnVisible(int column) const
-{
-    return ! hideColumns_.contains(column);
-}
-
-
 TrafficTab::TrafficTab(QWidget * parent) :
     DetachableTabWidget(parent)
 {
     _createModel = nullptr;
+    _createDelegate = nullptr;
     _disableTaps = false;
     _nameResolution = false;
     setTabBasename(QString());
@@ -241,32 +88,22 @@ void TrafficTab::setProtocolInfo(QString tableName, TrafficTypesList * trafficLi
 
     _recentColumnList = recentColumnList;
 
-    setOpenTabs(trafficList->selectedProtocols());
+    setOpenTabs(trafficList->protocols(true));
 }
 
-void TrafficTab::setDelegate(int column, ATapCreateDelegate createDelegate)
+void TrafficTab::setDelegate(ATapCreateDelegate createDelegate)
 {
-    if (! createDelegate || column < 0)
+    if (! createDelegate)
         return;
 
-    if (_createDelegates.keys().contains(column))
-        _createDelegates.remove(column);
-    _createDelegates.insert(column, createDelegate);
+    _createDelegate = createDelegate;
 
 
     for (int idx = 0; idx < count(); idx++) {
-        int setColumn = column;
-        ATapDataModel * model = modelForTabIndex(idx);
-        if (model->portsAreHidden()) {
-            if (model->modelType() == ATapDataModel::DATAMODEL_ENDPOINT && column > EndpointDataModel::ENDP_COLUMN_PORT)
-                setColumn -= 1;
-            else if (model->modelType() == ATapDataModel::DATAMODEL_CONVERSATION && column > ConversationDataModel::CONV_COLUMN_DST_PORT)
-                setColumn -= 2;
-        }
         if (qobject_cast<QTreeView *>(widget(idx)))
         {
             QTreeView * tree = qobject_cast<QTreeView *>(widget(idx));
-            tree->setItemDelegateForColumn(setColumn, createDelegate(tree));
+            tree->setItemDelegate(createDelegate(tree));
         }
     }
 }
@@ -277,20 +114,17 @@ QTreeView * TrafficTab::createTree(int protoId)
 
     if (_createModel) {
         ATapDataModel * model = _createModel(protoId, "");
+        model->setParent(tree);
         connect(model, &ATapDataModel::tapListenerChanged, tree, &TrafficTree::tapListenerEnabled);
 
         model->enableTap();
 
-        foreach(int col, _createDelegates.keys())
+        if (_createDelegate)
         {
-            if (_createDelegates[col])
-            {
-                ATapCreateDelegate creator = _createDelegates[col];
-                tree->setItemDelegateForColumn(col, creator(tree));
-            }
+            tree->setItemDelegate(_createDelegate(tree));
         }
 
-        TrafficDataFilterProxy * proxyModel = new TrafficDataFilterProxy();
+        TrafficDataFilterProxy * proxyModel = new TrafficDataFilterProxy(tree);
         proxyModel->setSourceModel(model);
         tree->setModel(proxyModel);
 
@@ -351,7 +185,6 @@ void TrafficTab::disableTap()
     }
 
     _disableTaps = true;
-    cornerWidget()->setEnabled(false);
     emit disablingTaps();
 }
 
