@@ -19,19 +19,19 @@
 /** The pattern object used for ws_mempbrk_exec().
  */
 typedef struct {
-    gchar patt[256];
+    char patt[256];
 #ifdef HAVE_SSE4_2
-    gboolean use_sse42;
+    bool use_sse42;
     __m128i mask;
 #endif
 } ws_mempbrk_pattern;
 
 /** Compile the pattern for the needles to find using ws_mempbrk_exec().
  */
-WS_DLL_PUBLIC void ws_mempbrk_compile(ws_mempbrk_pattern* pattern, const gchar *needles);
+WS_DLL_PUBLIC void ws_mempbrk_compile(ws_mempbrk_pattern* pattern, const char *needles);
 
 /** Scan for the needles specified by the compiled pattern.
  */
-WS_DLL_PUBLIC const guint8 *ws_mempbrk_exec(const guint8* haystack, size_t haystacklen, const ws_mempbrk_pattern* pattern, guchar *found_needle);
+WS_DLL_PUBLIC const uint8_t *ws_mempbrk_exec(const uint8_t* haystack, size_t haystacklen, const ws_mempbrk_pattern* pattern, unsigned char *found_needle);
 
 #endif /* __WS_MEMPBRK_H__ */
